Fallocate

Struct Fallocate 

pub struct Fallocate<'op> { /* private fields */ }
Allocate requested space.

If this operation is successful, the filesystem shall not report the error caused by the lack of free spaces to subsequent write requests.

Implementations

Source

impl<'op> Fallocate<'op>

pub fn ino(&self) -> u64

Return the number of target inode to be allocated the space.

pub fn fh(&self) -> u64

Return the handle for opened file.

pub fn offset(&self) -> u64

Return the starting point of region to be allocated.

pub fn length(&self) -> u64

Return the length of region to be allocated.

pub fn mode(&self) -> u32

Return the mode that specifies how to allocate the region.

See fallocate(2) for details.