pub struct Fallocate<'op> { /* private fields */ }Expand description
Allocate requested space.
If this operation is successful, the filesystem shall not report the error caused by the lack of free spaces to subsequent write requests.
Implementations