pub struct Open<'op> { /* private fields */ }Expand description
Open a file.
If the file is successfully opened, the filesystem must send the identifier
of the opened file handle to the kernel using ReplyOpen. This parameter is
set to a series of requests, such as read and write, until releasing
the file, and is able to be utilized as a “pointer” to the state during
handling the opened file.
See also the documentation of ReplyOpen for tuning the reply parameters.
Implementations
Sourceimpl<'op> Open<'op>
impl<'op> Open<'op>
Sourcepub fn flags(&self) -> u32
pub fn flags(&self) -> u32
Return the open flags.
The creating flags (O_CREAT, O_EXCL and O_NOCTTY) are removed and
these flags are handled by the kernel.
If the mount option contains -o default_permissions, the access mode flags
(O_RDONLY, O_WRONLY and O_RDWR) might be handled by the kernel and in that case,
these flags are omitted before issuing the request. Otherwise, the filesystem should
handle these flags and return an EACCES error when provided access mode is
invalid.